bayespy.inference.vmp.transformations.RotateVaryingMarkovChain.bound
====================================================================

.. currentmodule:: bayespy.inference.vmp.transformations

.. automethod:: RotateVaryingMarkovChain.bound